---

slug: /spatial-data-type-overview

---

# Overview of spatial data types

The geographic information system (GIS) feature of SeekDB supports the following spatial data types:

* `GEOMETRY`

* `POINT`

* `LINESTRING`

* `POLYGON`

* `MULTIPOINT`

* `MULTILINESTRING`

* `MULTIPOLYGON`

* `GEOMETRYCOLLECTION`

The `POINT`, `LINESTRING`, and `POLYGON` types are the basic types for storing single spatial data. They are extended from the `MULTIPOINT`, `MULTILINESTRING`, and `MULTIPOLYGON` collection types, respectively, to store collections of spatial data. However, they can only represent collections of their respective basic types. The `GEOMETRY` type is a virtual type that can represent any basic type. The `GEOMETRYCOLLECTION` type can be a collection of any `GEOMETRY` type.